@@ -1,20 +1,27 @@
+from __future__ import annotations
+
 import logging
-from typing import Sequence
+from typing import Iterable
 
 from sqlalchemy.exc import SQLAlchemyError
 
-from dbupgrade.db import update_sql
-from dbupgrade.files import FileInfo
+from .db import update_sql
+from .files import FileInfo
 
 
-def apply_files(db_url: str, files: Sequence[FileInfo]) -> bool:
+def apply_files(
+    db_url: str, files: Iterable[FileInfo]
+) -> tuple[list[FileInfo], FileInfo | None]:
+    applied: list[FileInfo] = []
     for file_info in files:
         try:
             apply_file(db_url, file_info)
         except SQLAlchemyError as exc:
             logging.error(str(exc))
-            return False
-    return True
+            return applied, file_info
+        else:
+            applied.append(file_info)
+    return applied, None
 
 
 def apply_file(db_url: str, file_info: FileInfo) -> None:
